@@ -11,7 +11,7 @@ use List::Util qw(reduce);
 use PYX::Parser;
 
 # Version.
-our $VERSION = 0.02;
+our $VERSION = 0.03;
 
 # Constructor.
 sub new {
@@ -259,12 +259,13 @@ L<PYX::Parser>.
 
 =head1 SEE ALSO
 
-L<PYX>,
-L<PYX::GraphViz>,
-L<PYX::Parser>,
-L<PYX::Stack>,
-L<PYX::Utils>,
-L<Task::PYX>.
+=over
+
+=item L<Task::PYX>
+
+Install the PYX modules.
+
+=back
 
 =head1 REPOSITORY
 
@@ -283,6 +284,6 @@ L<http://skim.cz>
 
 =head1 VERSION
 
-0.02
+0.03
 
 =cut
